@@ -7,7 +7,7 @@
     'name_es_CO': 'Secuencia de Sitio del Stock',
     'name_es_ES': 'Secuencia de ubicación de existencias',
     'name_fr_FR': 'Séquence emplacement',
-    'version': '2.0.0',
+    'version': '2.2.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -30,10 +30,13 @@
         'stock.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/cs_CZ.po',
+        'locale/bg_BG.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
